==> 1.0.2_20240315_release.zip: app/lang/zh-cn.php <==
<?php

$lang["sys"] = array(
    "dataExists" => "数据已存在",
    "dataNotExists" => "数据不存在",
    "noMethodDefined" => "方法未定义",
    "opFail" => "操作失败",
    "url_htm" => "静态",
    "url_php" => "动态",
    "url_rewrite" => "伪静态",
    "category" => "分类名称",
    "doNotRepeatOp" => "不要重复操作",
    "sendDoNotRepeatOp" => "已发送,不要重复操作",
    "rollbackDoNotRepeatOp" => "已回滚,不要重复操作",
    "insufficientDays" => "天数不足",
    "isPermanent" => "当前已是永久,不要重复操作",
    "isNotPermanent" => "当前已不是永久,不要重复操作",
    "execOver" => "无数据需生成",
    "cannotBeEmpty" => "{:fv1} 不能为空",
    "authTypeIncorrect" => "token类型不正确",
    "parsesFail" => "{:fv1} 解析失败",
    "validationFailed" => "验证失败",
    "handleTokenTimeLimit" => "拒绝处理",
    "expired" => "{:fv1} 已过期",
);

$lang["admin"] = array(
    "pleaseLogin" => "请先登录",
    "InsufficientPermissions" => "权限不足",
    "Function not configured to database" => "功能未配置到数据库",
    "Function not enabled" => "功能未启用",
    "Role disabled" => "角色已停用",
    "The advertising slot ID does not exist" => "广告位id不存在",
    "passwordErr" => "密码错误",
);

$lang["file"] = array(
    "cannotOpenFile" => "文件打开失败",
    "fileIsNotWritable" => "文件不可写入",
    "cannotWriteToFile" => "文件写入失败",
    "failedToLockFile" => "文件获得锁失败",

    "fileError" => "未知错误",
    "fileError1" => "上传文件超出配置上限",
    "fileError2" => "上传文件超出html表单限制",
    "fileError3" => "文件只有部分被上传",
    "fileError4" => "没有上传文件",
    "fileError6" => "没有找不到临时文件夹",
    "fileError7" => "文件写入失败",
    "fileError8" => "文件上传扩展file没有打开",

    "pleaseSelectTheUploadFile" => "请选择上传文件",
    "pleaseUsePostToUploadFiles" => "请使用POST上传文件",

    "fileMoveFailed" => "文件移动失败",
    "fileTypeNowAllow" => "文件类型{:fv1}不支持上传",
    "fileTooLarge" => "文件过大",
);
return $lang;

==> 1.0.20_20240718_release.zip: app/lang/zh-cn.php <==
<?php

$lang["sys"] = array(
    "updateKey" => "请先登录,如果已登录请重新登录。",
    "dataExists" => "数据已存在",
    "dataNotExists" => "数据不存在",
    "noMethodDefined" => "方法未定义",
    "opFail" => "操作失败",
    "url_htm" => "静态",
    "url_php" => "动态",
    "url_rewrite" => "伪静态",
    "category" => "分类名称",
    "doNotRepeatOp" => "不要重复操作",
    "sendDoNotRepeatOp" => "已发送,不要重复操作",
    "rollbackDoNotRepeatOp" => "已回滚,不要重复操作",
    "insufficientDays" => "天数不足",
    "isPermanent" => "当前已是永久,不要重复操作",
    "isNotPermanent" => "当前已不是永久,不要重复操作",
    "execOver" => "无数据需生成",
    "cannotBeEmpty" => "{:fv1} 不能为空",
    "authTypeIncorrect" => "token类型不正确",
    "parsesFail" => "{:fv1} 解析失败",
    "validationFailed" => "验证失败",
    "handleTokenTimeLimit" => "拒绝处理",
    "expired" => "{:fv1} 已过期",
    "pleaseAuthFirst" => "请先授权",
    "methodNotExists" => "{:method} 方法不存在",
    "classNotExists" => "{:class} 方法不存在",
    "execFail" => "执行失败",
    "verifyDataCannotBeEmpty" => "验证数据不能为空",
    "verifyRuleIsEmpty" => "验证规则不能为空",
);

$lang["admin"] = array(
    "pleaseLogin" => "请先登录",
    "InsufficientPermissions" => "权限不足",
    "Function not configured to database" => "功能未配置到数据库",
    "Function not enabled" => "功能未启用",
    "Role disabled" => "角色已停用",
    "The advertising slot ID does not exist" => "广告位id不存在",
    "passwordErr" => "密码错误",
    "captchaError" => "验证码错误",
);

$lang["table_ddl"] = array(
    "tableNotExists" => "{:table} 表不存在",
    "tableAddFieldFail" => "{:table} 添加字段 {:field} 失败",
    "tableFieldNotExists" => "{:table} 字段 {:field} 不存在",
    "tableFieldExists" => "{:table} 字段 {:field} 已存在",
);

$lang["file"] = array(
    "cannotOpenFile" => "文件打开失败",
    "fileIsNotWritable" => "文件不可写入",
    "cannotWriteToFile" => "文件写入失败",
    "failedToLockFile" => "文件获得锁失败",

    "fileError" => "未知错误",
    "fileError1" => "上传文件超出配置上限",
    "fileError2" => "上传文件超出html表单限制",
    "fileError3" => "文件只有部分被上传",
    "fileError4" => "没有上传文件",
    "fileError6" => "没有找不到临时文件夹",
    "fileError7" => "文件写入失败",
    "fileError8" => "文件上传扩展file没有打开",

    "pleaseSelectTheUploadFile" => "请选择上传文件",
    "pleaseUsePostToUploadFiles" => "请使用POST上传文件",

    "fileMoveFailed" => "文件移动失败",
    "fileTypeNowAllow" => "文件类型{:fv1}不支持上传",
    "fileTooLarge" => "文件过大",
);

$lang["cache"] = array(
    "updateFail" => "更新失败",
);
return $lang;
